@@ -6,6 +6,7 @@ from lyrebird.log import get_logger
 import subprocess
 import os
 import json
+import sys
 
 
 """
@@ -41,7 +42,6 @@ class LyrebirdProxyServer(ThreadServer):
         '''
         self.ignore_hosts = conf.get('proxy.ignore_hosts', None)
 
-
     def run(self):
         server_ip = application.config.get('ip')
         # info_msg(f'start on {server_ip}:{self.proxy_port}', f'{Fore.CYAN} ***请在被测设备上设置代理服务器地址***')
@@ -58,5 +58,4 @@ class LyrebirdProxyServer(ThreadServer):
         mitmenv = os.environ
         mitmenv['PROXY_PORT'] = str(application.config.get('mock.port', 9090))
         mitmenv['PROXY_FILTERS'] = json.dumps(application.config.get('proxy.filters', []))
-        subprocess.Popen(['python', MITMDUMP_FILE, *mitm_arguments], env=mitmenv)
-
+        subprocess.Popen(f'{sys.executable} {str(MITMDUMP_FILE)} {" ".join(mitm_arguments)}', shell=True, env=mitmenv)
